@@ -47,39 +47,50 @@ static connection* conn;
 
 static gint cursor_offset;
 static gint surround_length;
+static gboolean bDirectCommit;
 
 GType him_plugin_get_type(void){ return him_plugin_type; }
 
 
 gboolean him_plugin_requestCommit( GObject* plugin, GString gstr )
 {
-	g_debug("Received: \"%s\"", gstr.str );
+g_debug("him_plugin_requestCommit");
+
 	GString *newStr = g_string_new(gstr.str);
+	//g_debug("Received: \"%s\"", newStr->str );	
 
     	him_plugin_private* priv = HIM_PLUGIN_PRIVATE( plugin );
 
-	//Delete previous content if needed
-	hildon_im_ui_send_surrounding_offset( priv->ui, TRUE, surround_length - cursor_offset );
-	gint i;
-	for( i = 0; i < surround_length; i++ )
-	{
-	    hildon_im_ui_send_communication_message( priv->ui, HILDON_IM_CONTEXT_HANDLE_BACKSPACE );
-	}
-	gsize len = newStr->len;
-	gboolean newline = FALSE;
+    	if ( bDirectCommit )
+    	{
+		//Delete previous content if needed
+		hildon_im_ui_send_surrounding_offset( priv->ui, TRUE, surround_length - cursor_offset );
+		gint i;
+		for( i = 0; i < surround_length; i++ )
+		{
+		    hildon_im_ui_send_communication_message( priv->ui, HILDON_IM_CONTEXT_HANDLE_BACKSPACE );
+		}
+		gsize len = newStr->len;
+		gboolean newline = FALSE;
 
-	//Process last \n (if exists) like a system return
-	if(newStr->str[len -1] == '\n')
-	{
-		newline = TRUE;
-		newStr = g_string_truncate(newStr, len -1);
-	}
+		//Process last \n (if exists) like a system return
+		if(len > 0)
+		{
+			if(newStr->str[len-1] == '\n')
+			{
+				newline = TRUE;
+				newStr = g_string_truncate(newStr, len -1);
+			}
+		}
 	
-	g_debug("Writing: \"%s\"", gstr.str );
-	hildon_im_ui_send_utf8( priv->ui, newStr->str);		
-
-	if(newline)
-		hildon_im_ui_send_communication_message( priv->ui, HILDON_IM_CONTEXT_HANDLE_ENTER );
+		//g_debug("Writing: \"%s\"", gstr.str );
+		hildon_im_ui_send_utf8( priv->ui, newStr->str);	
+		
+		if(newline)
+			hildon_im_ui_send_communication_message( priv->ui, HILDON_IM_CONTEXT_HANDLE_ENTER );
+	}
+	else
+        	hildon_im_ui_send_surrounding_content( priv->ui, newStr->str );
 
 	return TRUE;
 }
@@ -87,6 +98,8 @@ gboolean him_plugin_requestCommit( GObject* plugin, GString gstr )
 /* called whenever the plug-in becomes available to the user */
 static void enable( HildonIMPlugin* plugin, gboolean init )
 {
+g_debug("enable");
+
 	/*  Send  g_debug() to the file log */
   	g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, LogToFile, NULL); 
 
@@ -94,11 +107,17 @@ static void enable( HildonIMPlugin* plugin, gboolean init )
     	priv->conn = conn;
     	connection_set( priv->conn, (GObject*)plugin, him_plugin_requestCommit );
 
+	Window win = hildon_im_ui_get_input_window( priv->ui );
+	bDirectCommit = isWindow(win);
         hildon_im_ui_send_communication_message( priv->ui, HILDON_IM_CONTEXT_REQUEST_SURROUNDING_FULL );
+        //hildon_im_ui_send_communication_message( priv->ui, HILDON_IM_CONTEXT_SURROUNDING_MODE );
 }
 
 static void surrounding_received( HildonIMPlugin *plugin, const gchar *surrounding, gint offset )
 {
+g_debug("surrounding_received");
+//g_debug("%s",surrounding);
+
     him_plugin_private* priv = HIM_PLUGIN_PRIVATE( plugin );
     
     cursor_offset = offset;
@@ -109,6 +128,8 @@ static void surrounding_received( HildonIMPlugin *plugin, const gchar *surroundi
 
 static void get_property( GObject* object, guint prop_id, GValue* value, GParamSpec* pspec )
 {
+//g_debug("get_property");
+
     him_plugin_private* priv;
 
     g_return_if_fail( HIM_PLUGIN(object) );
@@ -127,6 +148,8 @@ static void get_property( GObject* object, guint prop_id, GValue* value, GParamS
 
 static void set_property( GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec )
 {
+//g_debug("set_property");
+
     him_plugin_private* priv;
 
     g_return_if_fail( HIM_PLUGIN(object) );
@@ -143,26 +166,34 @@ static void set_property( GObject* object, guint prop_id, const GValue* value, G
 }
 static void finalize( GObject *object )
 {
+//g_debug("finalize");
+
     if ( G_OBJECT_CLASS( parent_class )->finalize )
         G_OBJECT_CLASS( parent_class )->finalize( object );
 }
 static void realize ( GtkWidget *widget )
 {
+//g_debug("realize");
+
     g_return_if_fail( HIM_PLUGIN(widget) );
     GTK_WIDGET_SET_FLAGS( widget, GTK_REALIZED );
 }
 
 static gboolean destroy( GtkWidget* widget, GdkEventAny* event )
 {
+//g_debug("destroy");
     return FALSE;
 }
 static gboolean expose( GtkWidget* widget, GdkEventExpose* event )
 {
+g_debug("expose");
     return TRUE;
 }
 
 static void him_plugin_class_init( him_plugin_class* klass )
 {
+//g_debug("him_plugin_class_init");
+
     GObjectClass* object_class;
     GtkWidgetClass* widget_class;
 
@@ -192,16 +223,22 @@ static void him_plugin_class_init( him_plugin_class* klass )
 
 GtkWidget* him_plugin_widget_new( HildonIMUI* widget )
 {    
+//g_debug("him_plugin_widget_new");
+
     return g_object_new( HIM_PLUGIN_TYPE, HILDON_IM_PROP_UI_DESCRIPTION, widget, NULL );
 }
 
 HildonIMPlugin* module_create( HildonIMUI* widget )
 {
+//g_debug("module_create");
+
     return HILDON_IM_PLUGIN( him_plugin_widget_new( widget ) );
 }
 
 const HildonIMPluginInfo* hildon_im_plugin_get_info( void )
 {
+//g_debug("hildon_im_plugin_get_info");
+
     static const HildonIMPluginInfo info = 
     {
         "FASTSMS-INPUT-PAD-PLUGIN",
@@ -246,39 +283,79 @@ void LogToFile (const gchar *log_domain, GLogLevelFlags log_level,
   fclose (logfile);
 } 
 
-static void him_plugin_init( him_plugin* plugin ){
-    /* Not implemented */    
+static void him_plugin_init( him_plugin* plugin )
+{
+    //g_debug("him_plugin_init");  
 }
 void module_exit( void )
 {
-    /* Not implemented */
+   //g_debug("module_exit");  
 }
-static void disable( HildonIMPlugin* plugin ){
-    /* Not implemented */
+static void disable( HildonIMPlugin* plugin )
+{
+/*    g_debug("Plugin disabling");
+
+    gchar* msg = NULL;
+    GError* error = NULL;
+    static DBusGConnection* conn = NULL;
+    static DBusGProxy* proxy = NULL;
+
+g_debug("conn");
+    if (!conn)
+        conn = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
+
+g_debug("proxy");
+    //open fastsms
+    if (!proxy )
+	proxy = dbus_g_proxy_new_for_name( conn, "it.rsc.fastsms", "/", "it.rsc.fastsms" );
+
+g_debug("call");
+    if ( !dbus_g_proxy_call( proxy, "commitRequest", &error, G_TYPE_INVALID, G_TYPE_STRING, msg, G_TYPE_INVALID ) ) 
+    {
+        g_debug( "failed to call: %s", error->message );
+        g_error_free(error);
+        return;
+    }
+
+g_debug("inizio");
+    GString *newStr = g_string_new(msg);
+    him_plugin_requestCommit((GObject*)plugin, *newStr);    
+g_debug("fine");*/
+
+    g_debug("Plugin disabled");
 }
-static void settings_changed( HildonIMPlugin* plugin, const gchar* key, const GConfValue* value ){
-    /* Not implemented */
+static void settings_changed( HildonIMPlugin* plugin, const gchar* key, const GConfValue* value )
+{
+    //g_debug("settings_changed");
 }
-static void language_settings_changed( HildonIMPlugin* plugin, const gint index ){
+static void language_settings_changed( HildonIMPlugin* plugin, const gint index )
+{
     /* Not implemented */
 }
 static void input_mode_changed( HildonIMPlugin* plugin ){
-    /* Not implemented */
+    g_debug("Input mode changed");
 }
 static void keyboard_state_changed( HildonIMPlugin* plugin ){
-    /* Not implemented */
+    g_debug("keyboard_state_changed");
 }
-static void client_widget_changed( HildonIMPlugin* plugin ){
-    /* Not implemented */
+static void client_widget_changed( HildonIMPlugin* plugin )
+{
+    /*him_plugin_private* priv = HIM_PLUGIN_PRIVATE( plugin );
+    Window win = hildon_im_ui_get_input_window( priv->ui );
+    g_debug("Client widget changed!!! %s",gtk_window_get_title(&win));*/
+    g_debug("Client widget changed!!!");
 }
 static void character_autocase( HildonIMPlugin* plugin ){
     /* Not implemented */
+
+//g_debug("character_autocase");
 }
 static void clear( HildonIMPlugin* plugin ){
+//g_debug("clear");
     /* Not implemented */
 }
 static void save_data( HildonIMPlugin* plugin ){
-    /* Not implemented */
+    //g_debug("save_data");
 }
 static void mode_a( HildonIMPlugin* plugin ){
     /* Not implemented */
@@ -299,26 +376,28 @@ static void tab( HildonIMPlugin* plugin ){
     /* Not implemented */
 }
 static void fullscreen( HildonIMPlugin* plugin, gboolean fullscreen ){
-    /* Not implemented */
+    //g_debug("fullscreen");
 }
 static void select_region( HildonIMPlugin *plugin, gint start, gint end ){
     /* Not implemented */
 }
 static void key_event( HildonIMPlugin *plugin, GdkEventType type, guint state, guint keyval, guint hardware_keycode ){
-    /* Not implemented */
+    //g_debug("key_event");
 }
 static void transition( HildonIMPlugin *plugin, gboolean from ){
-    /* Not implemented */
+    //g_debug("transition");
 }
 static void button_activated( HildonIMPlugin *plugin, HildonIMButton button, gboolean long_press ){
     /* Not implemented */
 }
 static void preedit_committed( HildonIMPlugin *plugin, const gchar *committed_preedit ){
-    /* Not implemented */
+    //g_debug("preedit_committed");
 }
 
 static void him_plugin_interface_init( HildonIMPluginIface* iface )
 {
+//g_debug("him_plugin_interface_init");
+
     iface->enable = enable;
     iface->disable = disable;
     iface->settings_changed = settings_changed;
@@ -346,6 +425,8 @@ static void him_plugin_interface_init( HildonIMPluginIface* iface )
 
 void module_init( GTypeModule* module )
 {
+//g_debug("module_init");
+
     static const GTypeInfo type_info = {
         sizeof( him_plugin_class ),
         NULL, /* base_init */
